@@ -19,20 +19,13 @@ describe 'swift::proxy::tempauth' do
     'concat { "/etc/swift/proxy-server.conf": }'
   end
 
-  let :fragment_file do
-    "/var/lib/puppet/concat/_etc_swift_proxy-server.conf/fragments/01_swift-proxy-swauth"
-  end
+  it { is_expected.to contain_concat_fragment('swift-proxy-tempauth').with_content(/\[filter:tempauth\]\nuse = egg:swift#tempauth/) }
+  it { is_expected.to contain_concat_fragment('swift-proxy-tempauth').with_content(/user_admin_admin = admin \.admin \.reseller_admin/) }
 
-  it { is_expected.to contain_file(fragment_file).with_content(/[filter:tempauth]/) }
-  it { is_expected.to contain_file(fragment_file).with_content(/use = egg:swift#tempauth/) }
-
-  it { is_expected.to_not contain_file(fragment_file).with_content(/reseller_prefix/) }
-  it { is_expected.to_not contain_file(fragment_file).with_content(/token_life/) }
-  it { is_expected.to_not contain_file(fragment_file).with_content(/auth_prefix/) }
-  it { is_expected.to_not contain_file(fragment_file).with_content(/storage_url_scheme/) }
-  it { is_expected.to contain_file(fragment_file).with_content(
-    /user_admin_admin = admin \.admin \.reseller_admin/
-  ) }
+  it { is_expected.to_not contain_concat_fragment('swift-proxy-tempauth').with_content(/reseller_prefix/) }
+  it { is_expected.to_not contain_concat_fragment('swift-proxy-tempauth').with_content(/token_life/) }
+  it { is_expected.to_not contain_concat_fragment('swift-proxy-tempauth').with_content(/auth_prefix/) }
+  it { is_expected.to_not contain_concat_fragment('swift-proxy-tempauth').with_content(/storage_url_scheme/) }
 
   context 'declaring two users' do
     let :params do {
@@ -51,10 +44,10 @@ describe 'swift::proxy::tempauth' do
         },
       ]
     } end
-    it { is_expected.to contain_file(fragment_file).with_content(
+    it { is_expected.to contain_concat_fragment('swift-proxy-tempauth').with_content(
       /user_admin_admin = admin \.admin \.reseller_admin/
     ) }
-    it { is_expected.to contain_file(fragment_file).with_content(
+    it { is_expected.to contain_concat_fragment('swift-proxy-tempauth').with_content(
       /user_bar_foo = pass \.reseller_admin/
     ) }
   end
@@ -70,9 +63,7 @@ describe 'swift::proxy::tempauth' do
         },
       ]
     } end
-    it { is_expected.to contain_file(fragment_file).with_content(
-      /user_admin_admin = admin $/
-    ) }
+    it { is_expected.to contain_concat_fragment('swift-proxy-tempauth').with_content(/user_admin_admin = admin $/) }
   end
 
 
@@ -85,10 +76,10 @@ describe 'swift::proxy::tempauth' do
     }.merge(default_params)
     end
 
-    it { is_expected.to contain_file(fragment_file).with_content(/reseller_prefix = AUTH/) }
-    it { is_expected.to contain_file(fragment_file).with_content(/token_life = 81600/) }
-    it { is_expected.to contain_file(fragment_file).with_content(/auth_prefix = \/auth\//) }
-    it { is_expected.to contain_file(fragment_file).with_content(/storage_url_scheme = http/) }
+    it { is_expected.to contain_concat_fragment('swift-proxy-tempauth').with_content(/reseller_prefix = AUTH/) }
+    it { is_expected.to contain_concat_fragment('swift-proxy-tempauth').with_content(/token_life = 81600/) }
+    it { is_expected.to contain_concat_fragment('swift-proxy-tempauth').with_content(/auth_prefix = \/auth\//) }
+    it { is_expected.to contain_concat_fragment('swift-proxy-tempauth').with_content(/storage_url_scheme = http/) }
 
     describe "invalid params" do
       ['account_user_list', 'token_life', 'auth_prefix', 'storage_url_scheme'].each do |param|
