@@ -2,7 +2,7 @@ require 'spec_helper'
 
 describe 'swift::storage::container' do
   let :pre_condition do
-    "class { 'swift': swift_hash_suffix => 'foo' }
+    "class { 'swift': swift_hash_path_suffix => 'foo' }
      class { 'swift::storage': storage_local_net_ip => '10.0.0.1' }"
   end
 
@@ -69,9 +69,10 @@ describe 'swift::storage::container' do
 
   context 'on Debian platforms' do
     let :facts do
-      {:operatingsystem => 'Ubuntu',
-       :osfamily        => 'Debian' }
-
+      OSDefaults.get_facts({
+        :osfamily        => 'Debian',
+        :operatingsystem => 'Ubuntu',
+      })
     end
 
     let :platform_params do
@@ -81,7 +82,7 @@ describe 'swift::storage::container' do
           'swift-container-updater'    => 'swift-container-updater',
           'swift-container-auditor'    => 'swift-container-auditor'
         },
-        :service_provider => 'upstart'
+        :service_provider => nil
       }
     end
 
@@ -111,8 +112,10 @@ describe 'swift::storage::container' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily        => 'RedHat',
-        :operatingsystem => 'RedHat' }
+      OSDefaults.get_facts({
+        :osfamily        => 'RedHat',
+        :operatingsystem => 'RedHat',
+      })
     end
 
     let :platform_params do
