@@ -1,11 +1,10 @@
 describe 'swift::storage::node' do
 
   let :facts do
-    {
+    OSDefaults.get_facts({
       :operatingsystem => 'Ubuntu',
       :osfamily        => 'Debian',
-      :processorcount  => 1
-    }
+    })
   end
 
   let :params do
@@ -20,7 +19,7 @@ describe 'swift::storage::node' do
   end
 
   let :pre_condition do
-    "class { 'swift': swift_hash_suffix => 'foo' }
+    "class { 'swift': swift_hash_path_suffix => 'foo' }
      class { 'swift::storage': storage_local_net_ip => '127.0.0.1' }"
   end
 
