@@ -2,16 +2,14 @@ require 'spec_helper'
 describe 'swift::storage::server' do
 
   let :facts do
-    {
+    OSDefaults.get_facts({
       :operatingsystem => 'Ubuntu',
       :osfamily        => 'Debian',
-      :processorcount  => 1
-    }
-
+    })
   end
 
   let :pre_condition do
-    "class { 'swift': swift_hash_suffix => 'foo' }
+    "class { 'swift': swift_hash_path_suffix => 'foo' }
      class { 'swift::storage': storage_local_net_ip => '10.0.0.1' }"
   end
   let :default_params do
@@ -58,9 +56,6 @@ describe 'swift::storage::server' do
         :enable     => true,
         :hasstatus  => true,
       )}
-      let :fragment_file do
-        "/var/lib/puppet/concat/_etc_swift_#{t}-server.conf/fragments/00_swift-#{t}-#{title}"
-      end
 
       describe 'when parameters are overridden' do
         {
@@ -72,11 +67,7 @@ describe 'swift::storage::server' do
         }.each do |k,v|
           describe "when #{k} is set" do
             let :params do req_params.merge({k => v}) end
-            it { is_expected.to contain_file(fragment_file) \
-              .with_content(
-                /^#{k.to_s}\s*=\s*#{v.is_a?(Array) ? v.join(' ') : v}\s*$/
-              )
-            }
+            it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^#{k.to_s}\s*=\s*#{v.is_a?(Array) ? v.join(' ') : v}\s*$/) }
           end
         end
         describe "when pipeline is passed an array" do
@@ -93,29 +84,23 @@ describe 'swift::storage::server' do
 
         describe "when replicator_concurrency is set" do
           let :params do req_params.merge({:replicator_concurrency => 42}) end
-          it { is_expected.to contain_file(fragment_file) \
-            .with_content(/\[#{t}-replicator\]\nconcurrency\s*=\s*42\s*$/m)
-          }
+          it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/\[#{t}-replicator\]\nconcurrency\s*=\s*42\s*$/m) }
         end
         if t != 'account'
           describe "when updater_concurrency is set" do
             let :params do req_params.merge({:updater_concurrency => 73}) end
-            it { is_expected.to contain_file(fragment_file) \
-              .with_content(/\[#{t}-updater\]\nconcurrency\s*=\s*73\s*$/m)
-            }
+            it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/\[#{t}-updater\]\nconcurrency\s*=\s*73\s*$/m) }
           end
         else
           describe "when reaper_concurrency is set" do
             let :params do req_params.merge({:reaper_concurrency => 4682}) end
-            it { is_expected.to contain_file(fragment_file) \
-              .with_content(/\[#{t}-reaper\]\nconcurrency\s*=\s*4682\s*$/m)
-            }
+            it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/\[#{t}-reaper\]\nconcurrency\s*=\s*4682\s*$/m) }
           end
         end
         if t == 'container'
           describe "when allow_versioning is set" do
            let :params do req_params.merge({ :allow_versions => false, }) end
-            it { is_expected.to contain_file(fragment_file).with_content(/\[app:container-server\]\nallow_versions\s*=\s*false\s*$/m)}
+            it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/\[app:container-server\]\nallow_versions\s*=\s*false\s*$/m) }
           end
         end
         describe "when log_udp_port is set" do
@@ -128,15 +113,15 @@ describe 'swift::storage::server' do
               { :log_udp_host => '127.0.0.1',
                 :log_udp_port => '514'})
             end
-            it { is_expected.to contain_file(fragment_file).with_content(/^log_udp_host\s*=\s*127\.0\.0\.1\s*$/) }
-            it { is_expected.to contain_file(fragment_file).with_content(/^log_udp_port\s*=\s*514\s*$/) }
+            it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^log_udp_host\s*=\s*127\.0\.0\.1\s*$/) }
+            it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^log_udp_port\s*=\s*514\s*$/) }
           end
         end
 
         describe "when using swift_#{t}_config resource" do
           let :pre_condition do
             "
-            class { 'swift': swift_hash_suffix => 'foo' }
+            class { 'swift': swift_hash_path_suffix => 'foo' }
             class { 'swift::storage': storage_local_net_ip => '10.0.0.1' }
             swift_#{t}_config { 'foo/bar': value => 'foo' }
             "
@@ -145,9 +130,7 @@ describe 'swift::storage::server' do
         end
         describe "when log_requests is turned off" do
           let :params do req_params.merge({:log_requests => false}) end
-          it { is_expected.to contain_file(fragment_file) \
-            .with_content(/^set log_requests\s*=\s*false\s*$/)
-          }
+          it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^set log_requests\s*=\s*false\s*$/) }
         end
       end
 
@@ -168,19 +151,20 @@ describe 'swift::storage::server' do
         )}
 
         # verify template lines
-        it { is_expected.to contain_file(fragment_file).with_content(/^devices\s*=\s*\/srv\/node\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^bind_ip\s*=\s*10\.0\.0\.1\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^bind_port\s*=\s*#{title}\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^mount_check\s*=\s*true\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^user\s*=\s*swift\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^set log_name\s*=\s*#{t}-server\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^set log_facility\s*=\s*LOG_LOCAL2\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^set log_level\s*=\s*INFO\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^set log_address\s*=\s*\/dev\/log\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^set log_requests\s*=\s*true\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^workers\s*=\s*1\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^concurrency\s*=\s*1\s*$/) }
-        it { is_expected.to contain_file(fragment_file).with_content(/^pipeline\s*=\s*#{t}-server\s*$/) }
+        it { is_expected.to contain_concat("/etc/swift/#{t}-server.conf").with_mode('0640') }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^devices\s*=\s*\/srv\/node\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^bind_ip\s*=\s*10\.0\.0\.1\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^bind_port\s*=\s*#{title}\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^mount_check\s*=\s*true\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^user\s*=\s*swift\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^set log_name\s*=\s*#{t}-server\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^set log_facility\s*=\s*LOG_LOCAL2\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^set log_level\s*=\s*INFO\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^set log_address\s*=\s*\/dev\/log\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^set log_requests\s*=\s*true\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^workers\s*=\s*1\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^concurrency\s*=\s*1\s*$/) }
+        it { is_expected.to contain_concat_fragment("swift-#{t}-#{title}").with_content(/^pipeline\s*=\s*#{t}-server\s*$/) }
       end
     end
   end
